==> HostCMS.Free_6.7.tar.gz: modules/informationsystem/group/i18n/ru.php <==
<?php
/**
 * Information systems.
 *
 * @package HostCMS
 * @subpackage Informationsystem
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Информационные группы',
	'information_system_top_menu_groups' => 'Информационная группа',
	'show_information_groups_link1' => 'Добавить',
	'show_information_groups_link4' => 'Дополнительные свойства',
	'information_groups_add_form_title' => 'Добавление информационной группы',
	'information_groups_edit_form_title' => 'Редактирование информационной группы',
	'tab_1' => 'Описание',
	'tab_2' => 'SEO',
	'tab_3' => 'Дополнительные свойства',

	'id' => 'Идентификатор',
	'informationsystem_id' => 'Идентификатор информационной системы',
	'name' => '<acronym title="Название информационной группы">Название информационной группы</acronym>',
	'description' => '<acronym title="Описание информационной группы">Описание информационной группы</acronym>',
	'exec_typograph_description' => '<acronym title="Типографировать описание информационной группы">Типографировать</acronym>',
	'use_trailing_punctuation' => '<acronym title="Оптическое выравнивание текста перемещает символы пунктуации за границу набора">Оптическое выравнивание</acronym>',

	'parent_id' => '<acronym title="Родительская группа информационной группы">Родительская группа</acronym>',
	'sorting' => '<acronym title="Порядок сортировки информационной группы">Порядок сортировки</acronym>',
	'path' => '<acronym title="Элемент URL информационной системы для группы">Путь</acronym>',
	'indexing' => '<acronym title="Флаг, указывающий индексировать информационную группу или нет">Индексировать</acronym>',

	'active' => '<acronym title="Статус активности информационной группы">Активна</acronym>',
	'siteuser_id' => '<acronym title="Идентификатор пользователя сайта, которому принадлежит информационная группа">
	Пользователь сайта</acronym>',

	'siteuser_group_id' => '<acronym title="Группа, имеющая права доступа к информационной группе">Группа доступа</acronym>',
	'information_parent' => 'Как у родителя',


	'image_large' => '<acronym title="Изображение для информационной группы">Изображение</acronym>',
	'image_small' => '<acronym title="Малое изображение для информационной группы">Малое изображение</acronym>',

	'seo_title' => '<acronym title="Значение мета-тега title для информационной группы">Заголовок (Title)</acronym>',
	'seo_description' => '<acronym title="Значение мета-тега description для информационной группы">Описание (Description)</acronym>',
	'seo_keywords' => '<acronym title="Значение мета-тега keywords для информационной группы">Ключевые слова (Keywords)</acronym>',

	'edit_success' => 'Информационная группа успешно добавлена.',
	//'edit_information_groups_success' => "Информационная группа успешно сохранена!",

	'edit_error' => 'Информационная группа не добавлена!',
	//'edit_information_groups_error' => "Ошибка! Информационная группа не изменена!",

	'markDeleted_success' => 'Информационная группа успешно удалена.',
	//'delete_information_groups_success' => "Информационные группы успешно удалены!",

	'markDeleted_error' => 'Информационная группа не удалена!',

	'error_URL_information_group' => 'В группе уже существует информационная подгруппа с таким URL!',
	'error_information_group_URL_add_edit_URL' => 'В группе существует информационный элемент с названием в URL, совпадающим с URL добавляемой/редактируемой подгруппы!',
	'changeActive_success' => 'Активность информационной группы изменена.',
	'changeIndexation_success' => 'Индексация информационной группы изменена.',
	'apply_success' => 'Информация изменена.',
	'copy_success' => 'Информационная группа скопирована!',

	'move_success' => 'Информационные группы перенесены.',
	'show_information_propertys_groups_title' => 'Дополнительные свойства групп информационной системы "%s"',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'tab_export' => 'Экспорт/Импорт',
	'guid' => '<acronym title="Уникальный идентификатор элемента, например ID00029527">GUID</acronym>',
	'tab_seo_templates' => 'Шаблоны SEO',
	'seo_group_header' => 'Шаблоны информационных групп',
	'seo_item_header' => 'Шаблоны информационных элементов',
	'seo_group_title_template' => 'Шаблон title',
	'seo_group_description_template' => 'Шаблон description',
	'seo_group_keywords_template' => 'Шаблон keywords',
	'seo_item_title_template' => 'Шаблон title',
	'seo_item_description_template' => 'Шаблон description',
	'seo_item_keywords_template' => 'Шаблон keywords',
	'markDeleted' => 'Удалить группу',
);

==> HostCMS.Free_7.0.tar.gz: modules/informationsystem/group/i18n/ru.php <==
<?php

return array(
	'model_name' => 'Информационные группы',
	'information_system_top_menu_groups' => 'Информационная группа',
	'show_information_groups_link1' => 'Добавить',
	'show_information_groups_link4' => 'Дополнительные свойства',
	'information_groups_add_form_title' => 'Добавление информационной группы',
	'information_groups_edit_form_title' => 'Редактирование информационной группы "%s"',
	'tab_1' => 'Описание',
	'tab_2' => 'SEO',
	'tab_3' => 'Дополнительные свойства',

	'id' => 'Идентификатор',
	'informationsystem_id' => 'Идентификатор информационной системы',
	'name' => 'Название информационной группы',
	'description' => 'Описание информационной группы',
	'exec_typograph_description' => 'Типографировать',
	'use_trailing_punctuation' => '<acronym title="Оптическое выравнивание текста перемещает символы пунктуации за границу набора">Оптическое выравнивание</acronym>',

	'parent_id' => 'Родительская группа',
	'sorting' => 'Порядок сортировки',
	'path' => 'Путь',
	'indexing' => 'Индексировать',

	'active' => 'Активна',
	'siteuser_id' => 'Клиент',

	'siteuser_group_id' => 'Группа клиентов',
	'information_parent' => 'Как у родителя',


	'image_large' => 'Изображение',
	'image_small' => 'Малое изображение',

	'seo_title' => 'Заголовок (Title)',
	'seo_description' => 'Описание (Description)',
	'seo_keywords' => 'Ключевые слова (Keywords)',

	'edit_success' => 'Информационная группа успешно добавлена.',
	'edit_error' => 'Информационная группа не добавлена!',
	'markDeleted_success' => 'Информационная группа успешно удалена.',
	'markDeleted_error' => 'Информационная группа не удалена!',

	'error_URL_information_group' => 'В группе уже существует информационная подгруппа с таким URL!',
	'error_information_group_URL_add_edit_URL' => 'В группе существует информационный элемент с названием в URL, совпадающим с URL добавляемой/редактируемой подгруппы!',
	'changeActive_success' => 'Активность информационной группы изменена.',
	'changeIndexation_success' => 'Индексация информационной группы изменена.',
	'apply_success' => 'Информация изменена.',
	'copy_success' => 'Информационная группа скопирована!',

	'move_success' => 'Информационные группы перенесены.',
	'show_information_propertys_groups_title' => 'Дополнительные свойства групп информационной системы "%s"',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'tab_export' => 'Экспорт/Импорт',
	'guid' => '<acronym title="Уникальный идентификатор элемента, например ID00029527">GUID</acronym>',
	'tab_seo_templates' => 'Шаблоны SEO',
	'seo_group_header' => 'Шаблоны информационных групп',
	'seo_item_header' => 'Шаблоны информационных элементов',
	'seo_group_title_template' => 'Шаблон title',
	'seo_group_description_template' => 'Шаблон description',
	'seo_group_keywords_template' => 'Шаблон keywords',
	'seo_group_h1_template' => 'Шаблон H1',
	'seo_item_title_template' => 'Шаблон title',
	'seo_item_description_template' => 'Шаблон description',
	'seo_item_keywords_template' => 'Шаблон keywords',
	'seo_item_h1_template' => 'Шаблон H1',
	'markDeleted' => 'Удалить группу',
	'shortcut_success' => "Ярлык группы успешно добавлен",
);
